@@ -1,4 +1,4 @@
-# Copyright 2014 - 2020 Avram Lubkin, All Rights Reserved
+# Copyright 2014 - 2023 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -23,13 +23,13 @@ from pkg_resources import iter_entry_points, EntryPoint
 from pluginlib.exceptions import PluginImportError, EntryPointWarning
 from pluginlib._objects import BlacklistEntry
 from pluginlib._parent import get_plugins
-from pluginlib._util import BASESTRING, LOGGER, NoneType, PY34, raise_with_traceback
+from pluginlib._util import BASESTRING, LOGGER, NoneType, PY2, raise_with_traceback
 
 try:
     from collections.abc import Iterable
 except ImportError:   # pragma: no cover
     # For Python < 3.3
-    from collections import Iterable
+    from collections import Iterable  # pylint: disable=deprecated-class
 
 
 def format_exception(etype, value, tback, limit=None):
@@ -114,7 +114,10 @@ def _import_module(name, path=None):
 
     if path is None:
         try:
-            loader = pkgutil.get_loader(name)
+            if PY2:
+                loader = pkgutil.get_loader(name)  # pragma: no cover
+            else:
+                loader = getattr(importlib.util.find_spec(name), 'loader', None)
         except ImportError:
             pass
         else:
@@ -172,7 +175,7 @@ def _recursive_path_import(path, prefix_package):
     for root, dirs, files in os.walk(path):
         # If root is a Python module, we won't walk any farther down it
         # find_module() seems to be recursive in Python 3
-        if '__init__.py' in files and (3, 0) <= sys.version_info[:2] < (3, 5):  # pragma: no cover
+        if '__init__.py' in files and not PY2:  # pragma: no cover
             dirs.clear()
             if root != path:
                 continue
@@ -189,12 +192,13 @@ def _recursive_path_import(path, prefix_package):
         for finder, name, is_pkg in pkgutil.walk_packages([root], prefix=prefix):
             LOGGER.debug('Attempting to load module %s from %s', name, finder.path)
             try:
-                # find_module() was deprecated in 3.4, but module_from_spec wasn't available
-                if PY34:  # pragma: no cover
+                # find_module() was deprecated in 3.4
+                if PY2:  # pragma: no cover
                     finder.find_module(name).load_module(name)
                 else:
                     spec = finder.find_spec(name)
                     module = importlib.util.module_from_spec(spec)
+                    sys.modules[name] = module
                     spec.loader.exec_module(module)
 
             except Exception as e:  # pylint: disable=broad-except
@@ -258,13 +262,13 @@ class PluginLoader(object):
         for argname, arg in (('modules', modules), ('paths', paths), ('blacklist', blacklist),
                              ('type_filter', type_filter)):
             if not isinstance(arg, (NoneType, Iterable)) or isinstance(arg, BASESTRING):
-                raise TypeError("Expecting iterable for '%s', recieved %s" % (argname, type(arg)))
+                raise TypeError("Expecting iterable for '%s', received %s" % (argname, type(arg)))
 
         # Make sure we got strings
         for argname, arg in (('library', library), ('entry_point', entry_point),
                              ('prefix_package', prefix_package)):
             if not isinstance(arg, (NoneType, BASESTRING)):
-                raise TypeError("Expecting string for '%s', recieved %s" % (argname, type(arg)))
+                raise TypeError("Expecting string for '%s', received %s" % (argname, type(arg)))
 
         self.group = group or '_default'
         self.library = library
