@@ -10,15 +10,10 @@
 This module contains pluginlib object classes
 """
 
+from collections import OrderedDict
 from pkg_resources import parse_version
 
-from pluginlib._util import BASESTRING, CachingDict, DictWithDotNotation, OPERATORS, PY26
-
-
-if PY26:
-    from ordereddict import OrderedDict  # pylint: disable=import-error  # pragma: no cover
-else:
-    from collections import OrderedDict
+from pluginlib._util import BASESTRING, CachingDict, DictWithDotNotation, OPERATORS
 
 
 class BlacklistEntry(object):
@@ -75,7 +70,7 @@ class BlacklistEntry(object):
             self.operator = operator
 
         if self.version is not None and not isinstance(self.version, BASESTRING):
-            raise TypeError('version must be a string, recieved %s' % type(self.version).__name__)
+            raise TypeError('version must be a string, received %s' % type(self.version).__name__)
 
         if self.operator is None:
             self.operator = '=='
