@@ -17,11 +17,12 @@ import warnings
 from pluginlib.exceptions import PluginWarning
 from pluginlib._objects import GroupDict, TypeDict, PluginDict
 from pluginlib._util import (allow_bare_decorator, ClassProperty, DictWithDotNotation,
-                             LOGGER, PY26, Undefined)
+                             LOGGER, Undefined)
 
 try:
     from asyncio import iscoroutinefunction
 except ImportError:  # pragma: no cover
+    # pylint: disable=unnecessary-lambda-assignment
     iscoroutinefunction = lambda func: False  # noqa: E731
 
 
@@ -29,8 +30,8 @@ DEFAULT = '_default'
 UNDEFINED = Undefined()
 
 isfunction = inspect.isfunction  # pylint: disable=invalid-name
-getfullargspec = getattr(inspect,  # pylint: disable=invalid-name
-                         'getfullargspec', getattr(inspect, 'getargspec'))
+# Support for deprecated method in 2.7
+getfullargspec = getattr(inspect, 'getfullargspec', getattr(inspect, 'getargspec', None))
 
 try:
     STR = unicode
@@ -185,9 +186,6 @@ class ClassInspector(object):
         if submethod is UNDEFINED or not isinstance(submethod, staticmethod):
             self.errorcode = 211
             self.message = 'Does not contain required static method (%s)' % name
-        elif PY26:  # pragma: no cover
-            self._compare_argspec(name, getfullargspec(method.__get__(True)),
-                                  getfullargspec(submethod.__get__(True)))
         else:
             self._compare_argspec(name, getfullargspec(method.__func__),
                                   getfullargspec(submethod.__func__))
@@ -205,9 +203,6 @@ class ClassInspector(object):
         if submethod is UNDEFINED or not isinstance(submethod, classmethod):
             self.errorcode = 212
             self.message = 'Does not contain required class method (%s)' % name
-        elif PY26:  # pragma: no cover
-            self._compare_argspec(name, getfullargspec(method.__get__(True).__func__),
-                                  getfullargspec(submethod.__get__(True).__func__))
         else:
             self._compare_argspec(name, getfullargspec(method.__func__),
                                   getfullargspec(submethod.__func__))
@@ -305,7 +300,7 @@ class PluginType(type):
         new = super(PluginType, cls).__new__(cls, name, bases, namespace, **kwargs)
 
         # Determine group
-        group = cls.__plugins.setdefault(new._group_ if new._group_ else DEFAULT, GroupDict())
+        group = cls.__plugins.setdefault(new._group_ or DEFAULT, GroupDict())
 
         if new._type_ in group:
             if new._parent_:
@@ -343,7 +338,7 @@ class PluginType(type):
         elif new._parent_:
             group[new._type_] = TypeDict(new)
 
-            new.__abstractmethods__ = dict()
+            new.__abstractmethods__ = {}
 
             # Get abstract methods by walking the MRO
             for base in reversed(new.__mro__):
@@ -361,7 +356,7 @@ class PluginType(type):
         Return registered plugins
         """
 
-        return cls.__plugins[cls._group_ if cls._group_ else DEFAULT][cls._type_]
+        return cls.__plugins[cls._group_ or DEFAULT][cls._type_]
 
 
 class Plugin(object):
@@ -476,11 +471,7 @@ class Parent(object):
         # In case we're inheriting another parent, clean registry
         if isinstance(cls, PluginType):
             plugins = cls._get_plugins().get(cls.name, {})
-            remove = []
-
-            for pver, pcls in plugins.items():
-                if cls is pcls:
-                    remove.append(pver)
+            remove = [pver for pver, pcls in plugins.items() if cls is pcls]
 
             if plugins and len(remove) == len(plugins):
                 del cls._get_plugins()[cls.name]
