@@ -15,14 +15,11 @@ import warnings
 from pluginlib import (abstractmethod, abstractproperty, abstractstaticmethod,
                        abstractclassmethod, abstractattribute)
 import pluginlib._parent as parent
+from pluginlib._util import PY2
 
 from tests import OUTPUT, TestCase, unittest
 
 
-NO_ASYNC = sys.version_info[:2] < (3, 5)
-PY2 = sys.version_info[0] < 3
-
-
 # pylint: disable=protected-access, no-member
 
 
@@ -105,7 +102,7 @@ class TestParent(TestCase):
         class Parent(object):
             """Parent"""
 
-            def hello(self):  # pylint: disable=no-self-use
+            def hello(self):
                 """Hello, world!"""
                 return 'world'
 
@@ -182,7 +179,7 @@ class TestPlugin(TestCase):
         class Parent(object):
             """Parent"""
 
-            def hello(self):  # pylint: disable=no-self-use
+            def hello(self):
                 """Hello, world!"""
                 return 'world'
 
@@ -499,7 +496,7 @@ class TestPluginType(TestCase):
         class Parent(object):
             """Parent with abstract property"""
 
-            @abstractproperty
+            @abstractproperty  # Python 2  # pylint: disable=deprecated-decorator
             def abstract(self):
                 """Abstract property"""
 
@@ -526,7 +523,7 @@ class TestPluginType(TestCase):
         self.prop(Parent)
         self.attr(Parent)
 
-    @unittest.skipIf(NO_ASYNC, 'Requires Python 3.5+')
+    @unittest.skipIf(PY2, 'Requires Python 3.5+')
     def test_abstract_coroutine(self):
         """Attribute required in subclass"""
 
@@ -692,7 +689,7 @@ class TestPluginType(TestCase):
     def coroutine(self, parent_class, error=None):
         """Test abstract coroutine method"""
 
-        if NO_ASYNC:
+        if PY2:
             return
 
         with warnings.catch_warnings(record=True) as e:
